@@ -17,33 +17,31 @@ from typing import Dict, List, Optional, Union  # noqa: F401
 
 from aries_cloudcontroller.uplink_util import bool_query
 
-from aries_cloudcontroller.model.admin_api_message_tracing import AdminAPIMessageTracing
 from aries_cloudcontroller.model.indy_cred_precis import IndyCredPrecis
-from aries_cloudcontroller.model.indy_pres_spec import IndyPresSpec
-from aries_cloudcontroller.model.v10_presentation_create_request_request import (
-    V10PresentationCreateRequestRequest,
+from aries_cloudcontroller.model.v20_pres_create_request_request import (
+    V20PresCreateRequestRequest,
 )
-from aries_cloudcontroller.model.v10_presentation_exchange import (
-    V10PresentationExchange,
+from aries_cloudcontroller.model.v20_pres_ex_record import V20PresExRecord
+from aries_cloudcontroller.model.v20_pres_ex_record_list import V20PresExRecordList
+from aries_cloudcontroller.model.v20_pres_problem_report_request import (
+    V20PresProblemReportRequest,
 )
-from aries_cloudcontroller.model.v10_presentation_exchange_list import (
-    V10PresentationExchangeList,
+from aries_cloudcontroller.model.v20_pres_proposal_request import V20PresProposalRequest
+from aries_cloudcontroller.model.v20_pres_send_request_request import (
+    V20PresSendRequestRequest,
 )
-from aries_cloudcontroller.model.v10_presentation_problem_report_request import (
-    V10PresentationProblemReportRequest,
+from aries_cloudcontroller.model.v20_pres_spec_by_format_request import (
+    V20PresSpecByFormatRequest,
 )
-from aries_cloudcontroller.model.v10_presentation_proposal_request import (
-    V10PresentationProposalRequest,
-)
-from aries_cloudcontroller.model.v10_presentation_send_request_request import (
-    V10PresentationSendRequestRequest,
+from aries_cloudcontroller.model.v20_presentation_send_request_to_proposal import (
+    V20PresentationSendRequestToProposal,
 )
 
 
-class PresentProofV10Api(Consumer):
+class PresentProofV20Api(Consumer):
     async def create_proof_request(
-        self, *, body: Optional[V10PresentationCreateRequestRequest] = None
-    ) -> V10PresentationExchange:
+        self, *, body: Optional[V20PresCreateRequestRequest] = None
+    ) -> V20PresExRecord:
         """Creates a presentation request not bound to any proposal or connection"""
         return await self.__create_proof_request(
             body=body,
@@ -64,7 +62,7 @@ class PresentProofV10Api(Consumer):
         referent: Optional[str] = None,
         start: Optional[str] = None
     ) -> List[IndyCredPrecis]:
-        """Fetch credentials for a presentation request from wallet"""
+        """Fetch credentials from wallet for presentation request"""
         return await self.__get_matching_credentials(
             pres_ex_id=pres_ex_id,
             count=count,
@@ -73,7 +71,7 @@ class PresentProofV10Api(Consumer):
             start=start,
         )
 
-    async def get_record(self, *, pres_ex_id: str) -> V10PresentationExchange:
+    async def get_record(self, *, pres_ex_id: str) -> V20PresExRecord:
         """Fetch a single presentation exchange record"""
         return await self.__get_record(
             pres_ex_id=pres_ex_id,
@@ -86,7 +84,7 @@ class PresentProofV10Api(Consumer):
         role: Optional[str] = None,
         state: Optional[str] = None,
         thread_id: Optional[str] = None
-    ) -> V10PresentationExchangeList:
+    ) -> V20PresExRecordList:
         """Fetch all present-proof exchange records"""
         return await self.__get_records(
             connection_id=connection_id,
@@ -96,10 +94,7 @@ class PresentProofV10Api(Consumer):
         )
 
     async def report_problem(
-        self,
-        *,
-        pres_ex_id: str,
-        body: Optional[V10PresentationProblemReportRequest] = None
+        self, *, pres_ex_id: str, body: Optional[V20PresProblemReportRequest] = None
     ) -> Dict:
         """Send a problem report for presentation exchange"""
         return await self.__report_problem(
@@ -108,8 +103,8 @@ class PresentProofV10Api(Consumer):
         )
 
     async def send_presentation(
-        self, *, pres_ex_id: str, body: Optional[IndyPresSpec] = None
-    ) -> V10PresentationExchange:
+        self, *, pres_ex_id: str, body: Optional[V20PresSpecByFormatRequest] = None
+    ) -> V20PresExRecord:
         """Sends a proof presentation"""
         return await self.__send_presentation(
             pres_ex_id=pres_ex_id,
@@ -117,16 +112,19 @@ class PresentProofV10Api(Consumer):
         )
 
     async def send_proposal(
-        self, *, body: Optional[V10PresentationProposalRequest] = None
-    ) -> V10PresentationExchange:
+        self, *, body: Optional[V20PresProposalRequest] = None
+    ) -> V20PresExRecord:
         """Sends a presentation proposal"""
         return await self.__send_proposal(
             body=body,
         )
 
     async def send_request(
-        self, *, pres_ex_id: str, body: Optional[AdminAPIMessageTracing] = None
-    ) -> V10PresentationExchange:
+        self,
+        *,
+        pres_ex_id: str,
+        body: Optional[V20PresentationSendRequestToProposal] = None
+    ) -> V20PresExRecord:
         """Sends a presentation request in reference to a proposal"""
         return await self.__send_request(
             pres_ex_id=pres_ex_id,
@@ -134,14 +132,14 @@ class PresentProofV10Api(Consumer):
         )
 
     async def send_request_free(
-        self, *, body: Optional[V10PresentationSendRequestRequest] = None
-    ) -> V10PresentationExchange:
+        self, *, body: Optional[V20PresSendRequestRequest] = None
+    ) -> V20PresExRecord:
         """Sends a free presentation request not bound to any proposal"""
         return await self.__send_request_free(
             body=body,
         )
 
-    async def verify_presentation(self, *, pres_ex_id: str) -> V10PresentationExchange:
+    async def verify_presentation(self, *, pres_ex_id: str) -> V20PresExRecord:
         """Verify a received presentation"""
         return await self.__verify_presentation(
             pres_ex_id=pres_ex_id,
@@ -149,19 +147,19 @@ class PresentProofV10Api(Consumer):
 
     @returns.json
     @json
-    @post("/present-proof/create-request")
+    @post("/present-proof-2.0/create-request")
     def __create_proof_request(
-        self, *, body: Body(type=V10PresentationCreateRequestRequest) = {}
-    ) -> V10PresentationExchange:
+        self, *, body: Body(type=V20PresCreateRequestRequest) = {}
+    ) -> V20PresExRecord:
         """Internal uplink method for create_proof_request"""
 
     @returns.json
-    @delete("/present-proof/records/{pres_ex_id}")
+    @delete("/present-proof-2.0/records/{pres_ex_id}")
     def __delete_record(self, *, pres_ex_id: str) -> Dict:
         """Internal uplink method for delete_record"""
 
     @returns.json
-    @get("/present-proof/records/{pres_ex_id}/credentials")
+    @get("/present-proof-2.0/records/{pres_ex_id}/credentials")
     def __get_matching_credentials(
         self,
         *,
@@ -174,12 +172,12 @@ class PresentProofV10Api(Consumer):
         """Internal uplink method for get_matching_credentials"""
 
     @returns.json
-    @get("/present-proof/records/{pres_ex_id}")
-    def __get_record(self, *, pres_ex_id: str) -> V10PresentationExchange:
+    @get("/present-proof-2.0/records/{pres_ex_id}")
+    def __get_record(self, *, pres_ex_id: str) -> V20PresExRecord:
         """Internal uplink method for get_record"""
 
     @returns.json
-    @get("/present-proof/records")
+    @get("/present-proof-2.0/records")
     def __get_records(
         self,
         *,
@@ -187,53 +185,53 @@ class PresentProofV10Api(Consumer):
         role: Query = None,
         state: Query = None,
         thread_id: Query = None
-    ) -> V10PresentationExchangeList:
+    ) -> V20PresExRecordList:
         """Internal uplink method for get_records"""
 
     @returns.json
     @json
-    @post("/present-proof/records/{pres_ex_id}/problem-report")
+    @post("/present-proof-2.0/records/{pres_ex_id}/problem-report")
     def __report_problem(
-        self,
-        *,
-        pres_ex_id: str,
-        body: Body(type=V10PresentationProblemReportRequest) = {}
+        self, *, pres_ex_id: str, body: Body(type=V20PresProblemReportRequest) = {}
     ) -> Dict:
         """Internal uplink method for report_problem"""
 
     @returns.json
     @json
-    @post("/present-proof/records/{pres_ex_id}/send-presentation")
+    @post("/present-proof-2.0/records/{pres_ex_id}/send-presentation")
     def __send_presentation(
-        self, *, pres_ex_id: str, body: Body(type=IndyPresSpec) = {}
-    ) -> V10PresentationExchange:
+        self, *, pres_ex_id: str, body: Body(type=V20PresSpecByFormatRequest) = {}
+    ) -> V20PresExRecord:
         """Internal uplink method for send_presentation"""
 
     @returns.json
     @json
-    @post("/present-proof/send-proposal")
+    @post("/present-proof-2.0/send-proposal")
     def __send_proposal(
-        self, *, body: Body(type=V10PresentationProposalRequest) = {}
-    ) -> V10PresentationExchange:
+        self, *, body: Body(type=V20PresProposalRequest) = {}
+    ) -> V20PresExRecord:
         """Internal uplink method for send_proposal"""
 
     @returns.json
     @json
-    @post("/present-proof/records/{pres_ex_id}/send-request")
+    @post("/present-proof-2.0/records/{pres_ex_id}/send-request")
     def __send_request(
-        self, *, pres_ex_id: str, body: Body(type=AdminAPIMessageTracing) = {}
-    ) -> V10PresentationExchange:
+        self,
+        *,
+        pres_ex_id: str,
+        body: Body(type=V20PresentationSendRequestToProposal) = {}
+    ) -> V20PresExRecord:
         """Internal uplink method for send_request"""
 
     @returns.json
     @json
-    @post("/present-proof/send-request")
+    @post("/present-proof-2.0/send-request")
     def __send_request_free(
-        self, *, body: Body(type=V10PresentationSendRequestRequest) = {}
-    ) -> V10PresentationExchange:
+        self, *, body: Body(type=V20PresSendRequestRequest) = {}
+    ) -> V20PresExRecord:
         """Internal uplink method for send_request_free"""
 
     @returns.json
-    @post("/present-proof/records/{pres_ex_id}/verify-presentation")
-    def __verify_presentation(self, *, pres_ex_id: str) -> V10PresentationExchange:
+    @post("/present-proof-2.0/records/{pres_ex_id}/verify-presentation")
+    def __verify_presentation(self, *, pres_ex_id: str) -> V20PresExRecord:
         """Internal uplink method for verify_presentation"""
